{
  inputs,
  pkgs,
  ...
}: {
  imports = with inputs; [
    self.nixosModules.desktop
    self.nixosModules.system
    self.nixosModules.config
    ./disko
    ./hardware
    ./misc
  ];

  networking = {
    networkmanager.enable = true;
    hostId = "31150fae";
    hostName = "sarien";
  };

  boot.loader.systemd-boot.enable = true;
  environment.memoryAllocator.provider = "mimalloc";
  system.stateVersion = "25.11";
  time.timeZone = "Europe/Kyiv";

  desktop.gnome.enable = true;
  services.displayManager.autoLogin = {
    enable = true;
    user = "user";
  };

  zramSwap.enable = true;
  swapDevices = [
    {
      device = "/swap/swapfile";
      size = 4 * 1024;
      priority = 100;
    }
    {
      device = "/swap/hibernate";
      size = 16 * 1024;
      priority = 0;
    }
  ];

  module = {
    config = {
      laptop.homeRowMods = true;
      powerSave = true;
      useIwd = true;
      vaapi = "intel-media-driver";
    };
    stylix = {
      enable = true;
      theme = "gruvbox-dark-pale";
    };
  };

  locale.ukrainian.enable = true;
  opentabletdriver.enable = false;
  qmk-vial.enable = true;
  virtual.libvirt.enable = true;
}
